@@ -1,42 +1,55 @@
 import os
 import json
 import random
-from pprint import pprint
+from pprint import pformat
 
 import requests
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 class ElectraAPI:
     URL = "https://app.ecpiot.co.il/mobile/mobilecommand"
+    HEADERS = {'user-agent': 'Electra Client'}
 
     MOCK_OS_DATA = {
         "os": "android",
         "osver": "M4B30Z",
     }
 
-    GLOBAL_VERBOSE = False
-
     @classmethod
     def post(cls, cmd, data, sid=None, os_details=False):
         if os_details:
             data = data.copy()
             data.update(cls.MOCK_OS_DATA)
-        response = requests.post(
-            cls.URL,
-            headers={'user-agent': 'Electra Client'},
-            json=dict(
-                pvdid=1,
-                id=999,
-                sid=sid,
-                cmd=cmd,
-                data=data
-            )
+        random_id = random.randint(1000, 1999)
+        post_data = dict(
+            pvdid=1,
+            id=random_id,
+            sid=sid,
+            cmd=cmd,
+            data=data
         )
-        j = response.json()
-        if cls.GLOBAL_VERBOSE:
-            pprint(j)
-        assert j['status'] == 0, "invalid status returned from command"
-        assert j['data']['res'] == 0, "invalid res returned from command"
+        logger.debug(f"Posting request\nid: {random_id}\nurl: {cls.URL}\nheaders: {cls.HEADERS}\n"
+                     f"post json data:\n{pformat(post_data)}")
+        try:
+            response = requests.post(
+                cls.URL,
+                headers=cls.HEADERS,
+                json=post_data,
+            )
+            j = response.json()
+        except:
+            logger.exception("ElectraAPI: Exception caught when posting to cloud service")
+            raise
+        logger.debug(f"Response received (id={random_id}):\n{pformat(j)}")
+        try:
+            assert j['status'] == 0, "invalid status returned from command"
+            assert j['data']['res'] == 0, "invalid res returned from command"
+        except:
+            logger.exception(f"Error status when posting command")
+            raise
         return j['data']
 
 
@@ -142,9 +155,9 @@ class AC:
 
     def renew_sid(self):
         self.sid = generate_sid(self.imei, self.token)
-        print("renewed sid:", self.sid)
+        logger.info(f"renewed sid: {self.sid}")
 
-    def modify_oper(self, *, ac_mode=None, fan_speed=None, temperature=None, ac_stsrc='WI-FI'):
+    def modify_oper(self, *, ac_mode=None, fan_speed=None, temperature=None, ac_stsrc='WI-FI', auto_on_off=True):
         status = self.status(check=True)
         new_oper = status['OPER']['OPER'].copy()
         if ac_mode is not None:
@@ -152,9 +165,17 @@ class AC:
         if fan_speed is not None:
             new_oper['FANSPD'] = fan_speed
         if temperature is not None:
+            if 'SPT' in new_oper:
+                temperature = int(temperature) if isinstance(new_oper['SPT'], int) else str(temperature)
             new_oper['SPT'] = temperature
         if ac_stsrc is not None and "AC_STSRC" in new_oper:
             new_oper['AC_STSRC'] = ac_stsrc
+        if auto_on_off:
+            if 'TURN_ON_OFF' in new_oper and ac_mode is not None:
+                if ac_mode == "STBY":
+                    new_oper['TURN_ON_OFF'] = "OFF"
+                else:
+                    new_oper['TURN_ON_OFF'] = "ON"
         self._post('SEND_COMMAND', dict(
             id=self.ac_id,
             commandJson=json.dumps({'OPER': new_oper})
